==> zio-aws-kms_2.13-6.20.103.2-sources.jar: zio/aws/kms/model/ConnectionErrorCodeType.scala <==
package zio.aws.kms.model
import scala.jdk.CollectionConverters._
sealed trait ConnectionErrorCodeType {
  def unwrap: software.amazon.awssdk.services.kms.model.ConnectionErrorCodeType
}
object ConnectionErrorCodeType {
  def wrap(
      value: software.amazon.awssdk.services.kms.model.ConnectionErrorCodeType
  ): zio.aws.kms.model.ConnectionErrorCodeType = value match {
    case software.amazon.awssdk.services.kms.model.ConnectionErrorCodeType.UNKNOWN_TO_SDK_VERSION =>
      val r = unknownToSdkVersion
      r
    case software.amazon.awssdk.services.kms.model.ConnectionErrorCodeType.INVALID_CREDENTIALS =>
      val r = INVALID_CREDENTIALS
      r
    case software.amazon.awssdk.services.kms.model.ConnectionErrorCodeType.CLUSTER_NOT_FOUND =>
      val r = CLUSTER_NOT_FOUND
      r
    case software.amazon.awssdk.services.kms.model.ConnectionErrorCodeType.NETWORK_ERRORS =>
      val r = NETWORK_ERRORS
      r
    case software.amazon.awssdk.services.kms.model.ConnectionErrorCodeType.INTERNAL_ERROR =>
      val r = INTERNAL_ERROR
      r
    case software.amazon.awssdk.services.kms.model.ConnectionErrorCodeType.INSUFFICIENT_CLOUDHSM_HSMS =>
      val r = INSUFFICIENT_CLOUDHSM_HSMS
      r
    case software.amazon.awssdk.services.kms.model.ConnectionErrorCodeType.USER_LOCKED_OUT =>
      val r = USER_LOCKED_OUT
      r
    case software.amazon.awssdk.services.kms.model.ConnectionErrorCodeType.USER_NOT_FOUND =>
      val r = USER_NOT_FOUND
      r
    case software.amazon.awssdk.services.kms.model.ConnectionErrorCodeType.USER_LOGGED_IN =>
      val r = USER_LOGGED_IN
      r
    case software.amazon.awssdk.services.kms.model.ConnectionErrorCodeType.SUBNET_NOT_FOUND =>
      val r = SUBNET_NOT_FOUND
      r
    case software.amazon.awssdk.services.kms.model.ConnectionErrorCodeType.INSUFFICIENT_FREE_ADDRESSES_IN_SUBNET =>
      val r = INSUFFICIENT_FREE_ADDRESSES_IN_SUBNET
      r
    case software.amazon.awssdk.services.kms.model.ConnectionErrorCodeType.XKS_PROXY_ACCESS_DENIED =>
      val r = XKS_PROXY_ACCESS_DENIED
      r
    case software.amazon.awssdk.services.kms.model.ConnectionErrorCodeType.XKS_PROXY_NOT_REACHABLE =>
      val r = XKS_PROXY_NOT_REACHABLE
      r
    case software.amazon.awssdk.services.kms.model.ConnectionErrorCodeType.XKS_VPC_ENDPOINT_SERVICE_NOT_FOUND =>
      val r = XKS_VPC_ENDPOINT_SERVICE_NOT_FOUND
      r
    case software.amazon.awssdk.services.kms.model.ConnectionErrorCodeType.XKS_PROXY_INVALID_RESPONSE =>
      val r = XKS_PROXY_INVALID_RESPONSE
      r
    case software.amazon.awssdk.services.kms.model.ConnectionErrorCodeType.XKS_PROXY_INVALID_CONFIGURATION =>
      val r = XKS_PROXY_INVALID_CONFIGURATION
      r
    case software.amazon.awssdk.services.kms.model.ConnectionErrorCodeType.XKS_VPC_ENDPOINT_SERVICE_INVALID_CONFIGURATION =>
      val r = XKS_VPC_ENDPOINT_SERVICE_INVALID_CONFIGURATION
      r
    case software.amazon.awssdk.services.kms.model.ConnectionErrorCodeType.XKS_PROXY_TIMED_OUT =>
      val r = XKS_PROXY_TIMED_OUT
      r
    case software.amazon.awssdk.services.kms.model.ConnectionErrorCodeType.XKS_PROXY_INVALID_TLS_CONFIGURATION =>
      val r = XKS_PROXY_INVALID_TLS_CONFIGURATION
      r
  }
  case object unknownToSdkVersion
      extends zio.aws.kms.model.ConnectionErrorCodeType {
    override def unwrap
        : software.amazon.awssdk.services.kms.model.ConnectionErrorCodeType =
      software.amazon.awssdk.services.kms.model.ConnectionErrorCodeType.UNKNOWN_TO_SDK_VERSION
  }
  case object INVALID_CREDENTIALS
      extends zio.aws.kms.model.ConnectionErrorCodeType {
    override def unwrap
        : software.amazon.awssdk.services.kms.model.ConnectionErrorCodeType =
      software.amazon.awssdk.services.kms.model.ConnectionErrorCodeType.INVALID_CREDENTIALS
  }
  case object CLUSTER_NOT_FOUND
      extends zio.aws.kms.model.ConnectionErrorCodeType {
    override def unwrap
        : software.amazon.awssdk.services.kms.model.ConnectionErrorCodeType =
      software.amazon.awssdk.services.kms.model.ConnectionErrorCodeType.CLUSTER_NOT_FOUND
  }
  case object NETWORK_ERRORS extends zio.aws.kms.model.ConnectionErrorCodeType {
    override def unwrap
        : software.amazon.awssdk.services.kms.model.ConnectionErrorCodeType =
      software.amazon.awssdk.services.kms.model.ConnectionErrorCodeType.NETWORK_ERRORS
  }
  case object INTERNAL_ERROR extends zio.aws.kms.model.ConnectionErrorCodeType {
    override def unwrap
        : software.amazon.awssdk.services.kms.model.ConnectionErrorCodeType =
      software.amazon.awssdk.services.kms.model.ConnectionErrorCodeType.INTERNAL_ERROR
  }
  case object INSUFFICIENT_CLOUDHSM_HSMS
      extends zio.aws.kms.model.ConnectionErrorCodeType {
    override def unwrap
        : software.amazon.awssdk.services.kms.model.ConnectionErrorCodeType =
      software.amazon.awssdk.services.kms.model.ConnectionErrorCodeType.INSUFFICIENT_CLOUDHSM_HSMS
  }
  case object USER_LOCKED_OUT
      extends zio.aws.kms.model.ConnectionErrorCodeType {
    override def unwrap
        : software.amazon.awssdk.services.kms.model.ConnectionErrorCodeType =
      software.amazon.awssdk.services.kms.model.ConnectionErrorCodeType.USER_LOCKED_OUT
  }
  case object USER_NOT_FOUND extends zio.aws.kms.model.ConnectionErrorCodeType {
    override def unwrap
        : software.amazon.awssdk.services.kms.model.ConnectionErrorCodeType =
      software.amazon.awssdk.services.kms.model.ConnectionErrorCodeType.USER_NOT_FOUND
  }
  case object USER_LOGGED_IN extends zio.aws.kms.model.ConnectionErrorCodeType {
    override def unwrap
        : software.amazon.awssdk.services.kms.model.ConnectionErrorCodeType =
      software.amazon.awssdk.services.kms.model.ConnectionErrorCodeType.USER_LOGGED_IN
  }
  case object SUBNET_NOT_FOUND
      extends zio.aws.kms.model.ConnectionErrorCodeType {
    override def unwrap
        : software.amazon.awssdk.services.kms.model.ConnectionErrorCodeType =
      software.amazon.awssdk.services.kms.model.ConnectionErrorCodeType.SUBNET_NOT_FOUND
  }
  case object INSUFFICIENT_FREE_ADDRESSES_IN_SUBNET
      extends zio.aws.kms.model.ConnectionErrorCodeType {
    override def unwrap
        : software.amazon.awssdk.services.kms.model.ConnectionErrorCodeType =
      software.amazon.awssdk.services.kms.model.ConnectionErrorCodeType.INSUFFICIENT_FREE_ADDRESSES_IN_SUBNET
  }
  case object XKS_PROXY_ACCESS_DENIED
      extends zio.aws.kms.model.ConnectionErrorCodeType {
    override def unwrap
        : software.amazon.awssdk.services.kms.model.ConnectionErrorCodeType =
      software.amazon.awssdk.services.kms.model.ConnectionErrorCodeType.XKS_PROXY_ACCESS_DENIED
  }
  case object XKS_PROXY_NOT_REACHABLE
      extends zio.aws.kms.model.ConnectionErrorCodeType {
    override def unwrap
        : software.amazon.awssdk.services.kms.model.ConnectionErrorCodeType =
      software.amazon.awssdk.services.kms.model.ConnectionErrorCodeType.XKS_PROXY_NOT_REACHABLE
  }
  case object XKS_VPC_ENDPOINT_SERVICE_NOT_FOUND
      extends zio.aws.kms.model.ConnectionErrorCodeType {
    override def unwrap
        : software.amazon.awssdk.services.kms.model.ConnectionErrorCodeType =
      software.amazon.awssdk.services.kms.model.ConnectionErrorCodeType.XKS_VPC_ENDPOINT_SERVICE_NOT_FOUND
  }
  case object XKS_PROXY_INVALID_RESPONSE
      extends zio.aws.kms.model.ConnectionErrorCodeType {
    override def unwrap
        : software.amazon.awssdk.services.kms.model.ConnectionErrorCodeType =
      software.amazon.awssdk.services.kms.model.ConnectionErrorCodeType.XKS_PROXY_INVALID_RESPONSE
  }
  case object XKS_PROXY_INVALID_CONFIGURATION
      extends zio.aws.kms.model.ConnectionErrorCodeType {
    override def unwrap
        : software.amazon.awssdk.services.kms.model.ConnectionErrorCodeType =
      software.amazon.awssdk.services.kms.model.ConnectionErrorCodeType.XKS_PROXY_INVALID_CONFIGURATION
  }
  case object XKS_VPC_ENDPOINT_SERVICE_INVALID_CONFIGURATION
      extends zio.aws.kms.model.ConnectionErrorCodeType {
    override def unwrap
        : software.amazon.awssdk.services.kms.model.ConnectionErrorCodeType =
      software.amazon.awssdk.services.kms.model.ConnectionErrorCodeType.XKS_VPC_ENDPOINT_SERVICE_INVALID_CONFIGURATION
  }
  case object XKS_PROXY_TIMED_OUT
      extends zio.aws.kms.model.ConnectionErrorCodeType {
    override def unwrap
        : software.amazon.awssdk.services.kms.model.ConnectionErrorCodeType =
      software.amazon.awssdk.services.kms.model.ConnectionErrorCodeType.XKS_PROXY_TIMED_OUT
  }
  case object XKS_PROXY_INVALID_TLS_CONFIGURATION
      extends zio.aws.kms.model.ConnectionErrorCodeType {
    override def unwrap
        : software.amazon.awssdk.services.kms.model.ConnectionErrorCodeType =
      software.amazon.awssdk.services.kms.model.ConnectionErrorCodeType.XKS_PROXY_INVALID_TLS_CONFIGURATION
  }
}

==> zio-aws-kms_3-5.17.160.1-sources.jar: zio/aws/kms/model/ConnectionErrorCodeType.scala <==
package zio.aws.kms.model
import scala.jdk.CollectionConverters.*
sealed trait ConnectionErrorCodeType {
  def unwrap: software.amazon.awssdk.services.kms.model.ConnectionErrorCodeType
}
object ConnectionErrorCodeType {
  def wrap(
      value: software.amazon.awssdk.services.kms.model.ConnectionErrorCodeType
  ): zio.aws.kms.model.ConnectionErrorCodeType = value match {
    case software.amazon.awssdk.services.kms.model.ConnectionErrorCodeType.UNKNOWN_TO_SDK_VERSION =>
      val r = unknownToSdkVersion
      r
    case software.amazon.awssdk.services.kms.model.ConnectionErrorCodeType.INVALID_CREDENTIALS =>
      val r = INVALID_CREDENTIALS
      r
    case software.amazon.awssdk.services.kms.model.ConnectionErrorCodeType.CLUSTER_NOT_FOUND =>
      val r = CLUSTER_NOT_FOUND
      r
    case software.amazon.awssdk.services.kms.model.ConnectionErrorCodeType.NETWORK_ERRORS =>
      val r = NETWORK_ERRORS
      r
    case software.amazon.awssdk.services.kms.model.ConnectionErrorCodeType.INTERNAL_ERROR =>
      val r = INTERNAL_ERROR
      r
    case software.amazon.awssdk.services.kms.model.ConnectionErrorCodeType.INSUFFICIENT_CLOUDHSM_HSMS =>
      val r = INSUFFICIENT_CLOUDHSM_HSMS
      r
    case software.amazon.awssdk.services.kms.model.ConnectionErrorCodeType.USER_LOCKED_OUT =>
      val r = USER_LOCKED_OUT
      r
    case software.amazon.awssdk.services.kms.model.ConnectionErrorCodeType.USER_NOT_FOUND =>
      val r = USER_NOT_FOUND
      r
    case software.amazon.awssdk.services.kms.model.ConnectionErrorCodeType.USER_LOGGED_IN =>
      val r = USER_LOGGED_IN
      r
    case software.amazon.awssdk.services.kms.model.ConnectionErrorCodeType.SUBNET_NOT_FOUND =>
      val r = SUBNET_NOT_FOUND
      r
  }
  case object unknownToSdkVersion
      extends zio.aws.kms.model.ConnectionErrorCodeType {
    override def unwrap
        : software.amazon.awssdk.services.kms.model.ConnectionErrorCodeType =
      software.amazon.awssdk.services.kms.model.ConnectionErrorCodeType.UNKNOWN_TO_SDK_VERSION
  }
  case object INVALID_CREDENTIALS
      extends zio.aws.kms.model.ConnectionErrorCodeType {
    override def unwrap
        : software.amazon.awssdk.services.kms.model.ConnectionErrorCodeType =
      software.amazon.awssdk.services.kms.model.ConnectionErrorCodeType.INVALID_CREDENTIALS
  }
  case object CLUSTER_NOT_FOUND
      extends zio.aws.kms.model.ConnectionErrorCodeType {
    override def unwrap
        : software.amazon.awssdk.services.kms.model.ConnectionErrorCodeType =
      software.amazon.awssdk.services.kms.model.ConnectionErrorCodeType.CLUSTER_NOT_FOUND
  }
  case object NETWORK_ERRORS extends zio.aws.kms.model.ConnectionErrorCodeType {
    override def unwrap
        : software.amazon.awssdk.services.kms.model.ConnectionErrorCodeType =
      software.amazon.awssdk.services.kms.model.ConnectionErrorCodeType.NETWORK_ERRORS
  }
  case object INTERNAL_ERROR extends zio.aws.kms.model.ConnectionErrorCodeType {
    override def unwrap
        : software.amazon.awssdk.services.kms.model.ConnectionErrorCodeType =
      software.amazon.awssdk.services.kms.model.ConnectionErrorCodeType.INTERNAL_ERROR
  }
  case object INSUFFICIENT_CLOUDHSM_HSMS
      extends zio.aws.kms.model.ConnectionErrorCodeType {
    override def unwrap
        : software.amazon.awssdk.services.kms.model.ConnectionErrorCodeType =
      software.amazon.awssdk.services.kms.model.ConnectionErrorCodeType.INSUFFICIENT_CLOUDHSM_HSMS
  }
  case object USER_LOCKED_OUT
      extends zio.aws.kms.model.ConnectionErrorCodeType {
    override def unwrap
        : software.amazon.awssdk.services.kms.model.ConnectionErrorCodeType =
      software.amazon.awssdk.services.kms.model.ConnectionErrorCodeType.USER_LOCKED_OUT
  }
  case object USER_NOT_FOUND extends zio.aws.kms.model.ConnectionErrorCodeType {
    override def unwrap
        : software.amazon.awssdk.services.kms.model.ConnectionErrorCodeType =
      software.amazon.awssdk.services.kms.model.ConnectionErrorCodeType.USER_NOT_FOUND
  }
  case object USER_LOGGED_IN extends zio.aws.kms.model.ConnectionErrorCodeType {
    override def unwrap
        : software.amazon.awssdk.services.kms.model.ConnectionErrorCodeType =
      software.amazon.awssdk.services.kms.model.ConnectionErrorCodeType.USER_LOGGED_IN
  }
  case object SUBNET_NOT_FOUND
      extends zio.aws.kms.model.ConnectionErrorCodeType {
    override def unwrap
        : software.amazon.awssdk.services.kms.model.ConnectionErrorCodeType =
      software.amazon.awssdk.services.kms.model.ConnectionErrorCodeType.SUBNET_NOT_FOUND
  }
}
